@@ -8,7 +8,7 @@
     - Call Terminal commands using python 3 (this one requires a nix machine)
 """
 
-__version__ = "0.1.6"
+__version__ = "0.1.8"
 __license__ = 'MIT'
 
 # from typing import *
@@ -23,6 +23,9 @@ import requests
 
 class domonic:
 
+    JS_MASTER = "assets/js/master.js"
+    CSS_STYLE = "assets/css/style.css"
+
     @staticmethod
     def get(url: str):
         ''' downloads html and converts to domonic '''
